#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

from zope.interface import Attribute, Interface
from zope.schema import Bool

from onf_website.shared.expengine.interfaces import EXPENGINE_CONTENT_TYPE
from pyams_content.features.header.interfaces import IHeaderRendererSettings
from pyams_file.schema import ImageField, MediaField
from pyams_i18n.schema import I18nTextLineField
from pyams_sequence.schema import InternalReferenceField


__docformat__ = 'restructuredtext'

from onf_website import _


class IDefaultHeaderRendererSettings(IHeaderRendererSettings):
    """Default ONF header renderer settings"""

    can_use_context_illustration = Attribute("Can use context illustration as background?")

    use_context_illustration = Bool(title=_("Use context illustration"),
                                    required=False,
                                    default=True)

    no_use_context_illustration = Bool(title=_("Don't use context illustration?"),
                                       required=False,
                                       default=False)

    background = MediaField(title=_("Background illustration"),
                            description=_("Image or video displayed in header background"),
                            required=False)

    heading = I18nTextLineField(title=_('header-heading', default="Heading"),
                                description=_("Heading displayed on top above background "
                                              "illustration"),
                                required=False)

    marianne = ImageField(title=_("Logo Marianne"),
                          description=_("First logo displayed in header"),
                          required=False)

    logo = ImageField(title=_("Logo ONF"),
                      description=_("Second logo displayed in header"),
                      required=False)

    accessibility_menu = Bool(title=_("Accessibility menu?"),
                              description=_("Set to 'no' to hide accessibility menu..."),
                              required=False,
                              default=True)

    search_menu = Bool(title=_("Search menu?"),
                       description=_("Set to 'no' to hide search menu..."),
                       required=False,
                       default=True)

    search_target = InternalReferenceField(title=_("Search form target"),
                                           description=_("Site or folder handling site search"),
                                           required=False)

    experiential_engine = InternalReferenceField(title=_("Experiential engine"),
                                                 description=_("Internal reference to "
                                                               "experiential engine to include "
                                                               "into search form"),
                                                 content_type=EXPENGINE_CONTENT_TYPE,
                                                 required=False)

    contact_menu = Bool(title=_("Contact link?"),
                        description=_("Set to 'no' to hide contact button..."),
                        required=False,
                        default=False)

    contact_target = InternalReferenceField(title=_("Contact link target"),
                                            description=_("Internal content displaying contact "
                                                          "information"),
                                            required=False)

    top = Attribute("Top links list")

    menus = Attribute("Header menus")

    social_links_header = I18nTextLineField(title=_("Social networks header"),
                                            description=_("Social networks links header title"),
                                            required=False)

    social = Attribute("Social links")


class IDefaultHeaderMenu(Interface):
    """Default header menu marker interface"""


class IDefaultHeaderMenusContainer(Interface):
    """Default header menus container interface"""
